==> checker-3.4.0.jar: annotated-jdk/src/jdk.javadoc/share/classes/com/sun/javadoc/RootDoc.java <==
/*
 * Copyright (c) 1998, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javadoc;

import org.checkerframework.common.value.qual.MinLen;

@Deprecated()
@SuppressWarnings("removal")
public interface RootDoc extends Doc, DocErrorReporter {

    String[] @MinLen(1) [] options();

    PackageDoc[] specifiedPackages();

    ClassDoc @MinLen(1) [] specifiedClasses();

    ClassDoc[] classes();

    PackageDoc packageNamed(String name);

    ClassDoc classNamed(String qualifiedName);
}

==> checker-3.5.0.jar: annotated-jdk/src/jdk.javadoc/share/classes/com/sun/javadoc/RootDoc.java <==
/*
 * Copyright (c) 1998, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javadoc;

import org.checkerframework.common.value.qual.MinLen;
import org.checkerframework.dataflow.qual.SideEffectFree;
import org.checkerframework.framework.qual.AnnotatedFor;

@AnnotatedFor({ "nullness", "value" })
@Deprecated()
@SuppressWarnings("removal")
public interface RootDoc extends Doc, DocErrorReporter {

    @SideEffectFree
    String[] @MinLen(1) [] options();

    PackageDoc[] specifiedPackages();

    @SideEffectFree
    ClassDoc @MinLen(1) [] specifiedClasses();

    @SideEffectFree
    ClassDoc[] classes();

    PackageDoc packageNamed(String name);

    ClassDoc classNamed(String qualifiedName);
}
